@@ -41,10 +41,7 @@ to group Notes together in intervals and chords."""
 
 	name = 'C'
 	octave = 4
-	dynamics = { 
-			"velocity" : 64, # Used when saving as midi [ 0-127 ]
-			"channel" : 1, # Used when saving as midi [0-16]
-		}
+	dynamics = {}
 
 	def __init__(self, name = 'C', octave = 4, dynamics = {}):
 		self.set_note(name, octave, dynamics)
